@@ -4,14 +4,18 @@ pub enum Alarm {
     On = 1
 }
 
+pub type Coordinate = f32;
+pub type BatteryUnit = f32;
+pub type Angle = f32;
+
 #[derive(Debug, Clone, Copy)]
 pub struct LGT92 {
-    pub latitude: f32,
-    pub longitude: f32,
+    pub latitude: Coordinate,
+    pub longitude: Coordinate,
     pub alarm: Alarm,
-    pub battery: f32,
-    pub roll: f32,
-    pub pitch: f32
+    pub battery: BatteryUnit,
+    pub roll: Angle,
+    pub pitch: Angle
 }
 
 impl From<u8> for Alarm {
